@@ -1,10 +1,8 @@
 extern crate rterm;
 
+use rterm::app::App;
+use rterm::Result;
 use std::env;
-use rterm::{
-    app::App,
-    Result,
-};
 
 fn usage() {
     println!("usage: rterm [-v] [-g geometry] [-f font] [-o file]");
@@ -42,7 +40,7 @@ fn _main() -> Result<()> {
             i += 1;
             continue;
         }
-        if arg.starts_with("-") {
+        if arg.starts_with('-') {
             usage();
             return Err("invalid option".into());
         }
@@ -51,7 +49,7 @@ fn _main() -> Result<()> {
     let mut app = App::new(geometry, font, log)?;
     app.run()?;
 
-    return Ok(());
+    Ok(())
 }
 
 fn main() {
