@@ -1,9 +1,7 @@
+use crate::glyph::{blank_glyph, Glyph};
 use std::mem;
-use crate::glyph::{
-    Glyph,
-    blank_glyph,
-};
 
+#[derive(Clone, Copy, Debug)]
 pub struct Cursor {
     pub glyph: Glyph,
     pub x: usize,
@@ -11,9 +9,6 @@ pub struct Cursor {
     // When cursor is at the right edge of the terminal, it does
     // not wrap to new line until one more character is input.
     pub wrap_next: bool,
-
-    saved_x: usize,
-    saved_y: usize,
 }
 
 impl Cursor {
@@ -21,22 +16,12 @@ impl Cursor {
         Cursor {
             glyph: blank_glyph(),
             wrap_next: false,
-            x: 0, y: 0,
-            saved_x: 0, saved_y: 0,
+            x: 0,
+            y: 0,
         }
     }
 
     pub fn reset(&mut self) {
         let _ = mem::replace(self, Cursor::new());
     }
-
-    pub fn save_pos(&mut self) {
-        self.saved_x = self.x;
-        self.saved_y = self.y;
-    }
-
-    pub fn load_pos(&mut self) {
-        self.x = self.saved_x;
-        self.y = self.saved_y;
-    }
 }
